<?php

/**
 * @file
 * Taxonomy Machine Name API File.
 */

/**
 * Provides a case-insensitive and trimmed matching.
 *
 * @param string     $machine_name
 *   Machine name of the term to search for.
 * @param int|object $vocabulary
 *   Vocabulary machine name to limit the search.
 *
 * @return array
 *   An array of matching term objects.
 */
function taxonomy_term_machine_name_load($machine_name, $vocabulary) {
  $conditions = array('machine_name' => trim($machine_name));

  // Support for machine_name form callback.
  $args = func_get_args();
  if (isset($args[2]['term']) && is_object($args[2]['term'])) {
    $vocabulary = $args[2]['term']->vocabulary_machine_name;
  }

  if (is_string($vocabulary)) {
    $vocabulary = taxonomy_vocabulary_machine_name_load($vocabulary);
  }

  if (is_object($vocabulary)) {
    $conditions['vid'] = $vocabulary->vid;
  }
  elseif (is_numeric($vocabulary)) {
    $conditions['vid'] = (int) $vocabulary;
  }

  return taxonomy_term_load_multiple(array(), $conditions);
}
